==> sorm4j-1.3.17-sources.jar: org/nkjmlab/sorm4j/internal/util/DriverManagerDataSource.java <==
package org.nkjmlab.sorm4j.internal.util;

import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.SQLFeatureNotSupportedException;
import java.util.logging.Logger;
import javax.sql.DataSource;

/**
 * A database connection source wrapped a {@link DriverManager}
 *
 * @author nkjm
 *
 */

public class DriverManagerDataSource implements DataSource {

  private final String jdbcUrl;
  private final String username;
  private final String password;

  public DriverManagerDataSource(String jdbcUrl, String username, String password) {
    this.jdbcUrl = jdbcUrl;
    this.username = username;
    this.password = password;
  }

  @Override
  public Connection getConnection() throws SQLException {
    return Try.getOrThrow(() -> DriverManager.getConnection(jdbcUrl, username, password),
        Try::rethrow);
  }

  @Override
  public Logger getParentLogger() throws SQLFeatureNotSupportedException {
    throw new UnsupportedOperationException();
  }

  @Override
  public <T> T unwrap(Class<T> iface) throws SQLException {
    throw new UnsupportedOperationException();
  }

  @Override
  public boolean isWrapperFor(Class<?> iface) throws SQLException {
    throw new UnsupportedOperationException();
  }

  @Override
  public Connection getConnection(String username, String password) throws SQLException {
    return Try.getOrThrow(() -> DriverManager.getConnection(jdbcUrl, username, password),
        Try::rethrow);
  }

  @Override
  public PrintWriter getLogWriter() throws SQLException {
    return DriverManager.getLogWriter();
  }

  @Override
  public void setLogWriter(PrintWriter out) throws SQLException {
    DriverManager.setLogWriter(out);
  }

  @Override
  public void setLoginTimeout(int seconds) throws SQLException {
    DriverManager.setLoginTimeout(seconds);
  }

  @Override
  public int getLoginTimeout() throws SQLException {
    return DriverManager.getLoginTimeout();
  }

}

==> sorm4j-1.4.0-rc7-sources.jar: org/nkjmlab/sorm4j/internal/util/DriverManagerDataSource.java <==
package org.nkjmlab.sorm4j.internal.util;

import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.SQLFeatureNotSupportedException;
import java.util.logging.Logger;
import javax.sql.DataSource;

/**
 * A database connection source wrapped a {@link DriverManager}
 *
 * @author nkjm
 *
 */

public class DriverManagerDataSource implements DataSource {

  private final String jdbcUrl;
  private final String username;
  private final String password;

  public DriverManagerDataSource(String jdbcUrl, String username, String password) {
    this.jdbcUrl = jdbcUrl;
    this.username = username;
    this.password = password;
  }

  @Override
  public Connection getConnection() throws SQLException {
    return Try.getOrElseThrow(
        () -> username != null ? DriverManager.getConnection(jdbcUrl, username, password)
            : DriverManager.getConnection(jdbcUrl),
        Try::rethrow);
  }

  @Override
  public Logger getParentLogger() throws SQLFeatureNotSupportedException {
    throw new UnsupportedOperationException();
  }

  @Override
  public <T> T unwrap(Class<T> iface) throws SQLException {
    throw new UnsupportedOperationException();
  }

  @Override
  public boolean isWrapperFor(Class<?> iface) throws SQLException {
    throw new UnsupportedOperationException();
  }

  @Override
  public Connection getConnection(String username, String password) throws SQLException {
    return Try.getOrElseThrow(() -> DriverManager.getConnection(jdbcUrl, username, password),
        Try::rethrow);
  }

  @Override
  public PrintWriter getLogWriter() throws SQLException {
    return DriverManager.getLogWriter();
  }

  @Override
  public void setLogWriter(PrintWriter out) throws SQLException {
    DriverManager.setLogWriter(out);
  }

  @Override
  public void setLoginTimeout(int seconds) throws SQLException {
    DriverManager.setLoginTimeout(seconds);
  }

  @Override
  public int getLoginTimeout() throws SQLException {
    return DriverManager.getLoginTimeout();
  }

}
